summaryrefslogtreecommitdiff
path: root/sources/shared/Config.java
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2009-02-18 22:36:15 +0000
committerPaul Buetow <paul@buetow.org>2009-02-18 22:36:15 +0000
commita1267fb1830ecbca0c5e3939ab2f0cea8386c562 (patch)
treed19c9795996a24a11bd0071fdad5d132ca1dec42 /sources/shared/Config.java
parent832b02ef0fbf477dbd73dcedfbfb5c9093b82c8c (diff)
renamed config.txt into netcalendar.conf
Diffstat (limited to 'sources/shared/Config.java')
-rw-r--r--sources/shared/Config.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/sources/shared/Config.java b/sources/shared/Config.java
index 92484b2..40e561c 100644
--- a/sources/shared/Config.java
+++ b/sources/shared/Config.java
@@ -6,13 +6,13 @@ import java.io.*;
/**
* This class makes all the configuration options available to all the other classes and objects
* of this program. Its reading and writing back the values from and to the config.txt file.
* @author buetow
*
*/
public final class Config {
public static final String VERSION = "NetCalendar 1.1 SVN";
- private static final String CONFIG_FILE = "config.txt";
+ private static final String CONFIG_FILE = "netcalendar.conf";
private static HashMap mapConfigVals;
/**
@@ -66,7 +66,7 @@ public final class Config {
}
/**
* This methods reads the options from the calendar config file 'config.txt'.
* @param sConfigFile Specifies the relative or absolute path to the config file.
*/
public static void readConfig(String sConfigFile) {
@@ -211,7 +211,7 @@ public final class Config {
}
/**
* This method writes the current configuration to the config file "config.txt".
*/
public static void writeConfigToFile() {
String [] sKeys = getSortedKeyArray();
@@ -6,13 +6,13 @@ import java.io.*;
/**
* This class makes all the configuration options available to all the other classes and objects
- * of this program. Its reading and writing back the values from and to the config.txt file.
+ * of this program. Its reading and writing back the values from and to the netcalendar.conf file.
* @author buetow
*
@@ -66,7 +66,7 @@ public final class Config {
}
/**
- * This methods reads the options from the calendar config file 'config.txt'.
+ * This methods reads the options from the calendar config file 'netcalendar.conf'.
* @param sConfigFile Specifies the relative or absolute path to the config file.
*/
@@ -211,7 +211,7 @@ public final class Config {
}
/**
- * This method writes the current configuration to the config file "config.txt".
+ * This method writes the current configuration to the config file "netcalendar.conf".
*/
public static void writeConfigToFile() {